Turbine Installation API
========================

For detailed methodology, please see
:doc:`Turbine Installation Methodology <doc_TurbineInstall>`.

.. automodule:: ORBIT.phases.install.turbine_install.standard
   :members:
   :exclude-members: extract_vessel_specs

.. automodule:: ORBIT.phases.install.turbine_install._common
   :members:

.. automodule:: ORBIT.phases.install.turbine_install._single_wtiv
   :members:

.. automodule:: ORBIT.phases.install.turbine_install._wtiv_with_feeders
   :members:
